@@ -1,5 +1,5 @@
-from creds import db
-from models import liked_songs, song_list, news
+from .creds import db
+from .models import liked_songs, song_list, news
 from datetime import datetime
 import sqlalchemy as sql
 from sqlalchemy import update
